summaryrefslogtreecommitdiffstats
path: root/kspread/kspread_view.h
diff options
context:
space:
mode:
Diffstat (limited to 'kspread/kspread_view.h')
-rw-r--r--kspread/kspread_view.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kspread/kspread_view.h b/kspread/kspread_view.h
index 4a64a52e..4d6eb96f 100644
--- a/kspread/kspread_view.h
+++ b/kspread/kspread_view.h
@@ -407,10 +407,10 @@ public slots:
void toggleProtectSheet( bool );
void toggleProtectDoc( bool );
void viewZoom( const TQString & );
- void tqfind();
+ void find();
void findNext();
void findPrevious();
- void tqreplace();
+ void replace();
void conditional();
void validity();
void insertSeries();
@@ -638,7 +638,7 @@ protected slots:
void slotListChoosePopupMenu( );
/**
* Called by tqfind/tqreplace (findNext) when it found a match
*/
void slotHighlight( const TQString &text, int matchingIndex, int matchedLength );
/**
@@ -638,7 +638,7 @@ protected slots:
void slotListChoosePopupMenu( );
/**
- * Called by tqfind/tqreplace (findNext) when it found a match
+ * Called by find/replace (findNext) when it found a match
*/
void slotHighlight( const TQString &text, int matchingIndex, int matchedLength );